@@ -40,9 +40,6 @@ allowed_alarm_sort_by = {'alarm_id', 'alarm_definition_id',
                          'created_timestamp'}
 allowed_definition_sort_by = {'id', 'name', 'severity', 'updated_at', 'created_at'}
 
-# Notification valid types
-notification_types = ['EMAIL', 'WEBHOOK', 'PAGERDUTY']
-
 
 @utils.arg('name', metavar='<METRIC_NAME>',
            help='Name of the metric to create.')
@@ -554,21 +551,14 @@ def do_metric_statistics(mc, args):
                 formatters=formatters)
 
 
-def _validate_notification_period(period, notification_type):
-    if notification_type != 'WEBHOOK' and period != 0:
-        print("Invalid period, can only be non zero for webhooks")
-        return False
-    return True
-
-
 @utils.arg('name', metavar='<NOTIFICATION_NAME>',
            help='Name of the notification to create.')
 @utils.arg('type', metavar='<TYPE>',
-           help='The notification type. Type must be EMAIL, WEBHOOK, or PAGERDUTY.')
+           help='The notification type. See monasca notification-type-list for supported types.')
 @utils.arg('address', metavar='<ADDRESS>',
            help='A valid EMAIL Address, URL, or SERVICE KEY.')
 @utils.arg('--period', metavar='<PERIOD>', type=int, default=0,
-           help='A period for the notification method. Can only be non zero with webhooks')
+           help='A period for the notification method.')
 def do_notification_create(mc, args):
     '''Create notification.'''
 
@@ -577,8 +567,6 @@ def do_notification_create(mc, args):
     fields['type'] = args.type
     fields['address'] = args.address
     if args.period:
-        if not _validate_notification_period(args.period, args.type.upper()):
-            return
         fields['period'] = args.period
     try:
         notification = mc.notifications.create(**fields)
@@ -692,11 +680,11 @@ def do_notification_delete(mc, args):
 @utils.arg('name', metavar='<NOTIFICATION_NAME>',
            help='Name of the notification.')
 @utils.arg('type', metavar='<TYPE>',
-           help='The notification type. Type must be either EMAIL, WEBHOOK, or PAGERDUTY.')
+           help='The notification type. See monasca notification-type-list for supported types.')
 @utils.arg('address', metavar='<ADDRESS>',
            help='A valid EMAIL Address, URL, or SERVICE KEY.')
 @utils.arg('period', metavar='<PERIOD>', type=int,
-           help='A period for the notification method. Can only be non zero with webhooks')
+           help='A period for the notification method.')
 def do_notification_update(mc, args):
     '''Update notification.'''
     fields = {}
@@ -705,8 +693,6 @@ def do_notification_update(mc, args):
 
     fields['type'] = args.type
     fields['address'] = args.address
-    if not _validate_notification_period(args.period, args.type.upper()):
-        return
     fields['period'] = args.period
     try:
         notification = mc.notifications.update(**fields)
@@ -721,11 +707,11 @@ def do_notification_update(mc, args):
 @utils.arg('--name', metavar='<NOTIFICATION_NAME>',
            help='Name of the notification.')
 @utils.arg('--type', metavar='<TYPE>',
-           help='The notification type. Type must be either EMAIL, WEBHOOK, or PAGERDUTY.')
+           help='The notification type. See monasca notification-type-list for supported types.')
 @utils.arg('--address', metavar='<ADDRESS>',
            help='A valid EMAIL Address, URL, or SERVICE KEY.')
 @utils.arg('--period', metavar='<PERIOD>', type=int,
-           help='A period for the notification method. Can only be non zero with webhooks')
+           help='A period for the notification method.')
 def do_notification_patch(mc, args):
     '''Patch notification.'''
     fields = {}
@@ -738,9 +724,6 @@ def do_notification_patch(mc, args):
     if args.address:
         fields['address'] = args.address
     if args.period or args.period == 0:
-        if args.type and not _validate_notification_period(
-                args.period, args.type.upper()):
-            return
         fields['period'] = args.period
     try:
         notification = mc.notifications.patch(**fields)
@@ -1195,10 +1178,10 @@ def do_alarm_update(mc, args):
     fields = {}
     fields['alarm_id'] = args.id
     if args.state.upper() not in state_types:
-            errmsg = ('Invalid state, not one of [' +
-                      ', '.join(state_types) + ']')
-            print(errmsg)
-            return
+        errmsg = ('Invalid state, not one of [' +
+                  ', '.join(state_types) + ']')
+        print(errmsg)
+        return
     fields['state'] = args.state
     fields['lifecycle_state'] = args.lifecycle_state
     fields['link'] = args.link
@@ -1257,8 +1240,8 @@ def do_alarm_delete(mc, args):
 
 def output_alarm_history(args, alarm_history):
     if args.json:
-            print(utils.json_formatter(alarm_history))
-            return
+        print(utils.json_formatter(alarm_history))
+        return
     # format output
     cols = ['alarm_id', 'new_state', 'old_state', 'reason',
             'reason_data', 'metric_name', 'metric_dimensions', 'timestamp']
